<?php

/**
 * @file
 * sushibar's theme implementation for template functions
 */

include_once drupal_get_path('theme', 'sushibar') . '/common.inc';
/**
 * Hook theme.
 */

function sushibar_theme() {
  $items = array();
  $items['render_panel'] = array(
    "variables" => array(
      'page' => array(),
      'panels_list' => array(),
      'panel_regions_width' => array(),
    ),
    'preprocess functions' => array(
      'sushibar_preprocess_render_panel',
    ),
    'template' => 'panel',
    'path' => drupal_get_path('theme', 'sushibar') . '/tpl',
  );

$items['banner_output'] = array(
    'variables' => array(
      'url'             => NULL,
      'text'            => NULL,
      'link'            => NULL,
      'display_setting' => NULL,
      'display_errors'  => NULL,
      ),
    'path'      => drupal_get_path('theme', 'sushibar') . '/tpl',
    'template'  => 'banner_output_template',
    );

  return $items;
}

/**
 * Hook process html.
 */

function sushibar_preprocess_html(&$vars) {
  $current_skin = theme_get_setting('skin');
  if (isset($_COOKIE['weebpal_skin'])) {
    $current_skin = $_COOKIE['weebpal_skin'];
  }
  if (!empty($current_skin) && $current_skin != 'default') {
    $vars['classes_array'][] = 'skin-' . $current_skin;
  }

  $current_background = theme_get_setting('background');
  if (isset($_COOKIE['weebpal_background'])) {
    $current_background = $_COOKIE['weebpal_background'];
  }
  if (!empty($current_background)) {
    //$vars['classes'] .= ' ' . $current_background;
    $vars['classes_array'][] = $current_background;
  }

}

/**
 * Hook preprocess page.
 */

function sushibar_preprocess_page(&$vars) {
  global $theme_key;
  $vars['page_css'] = '';

  $vars['regions_width'] = sushibar_regions_width($vars['page']);
  $panel_regions = sushibar_panel_regions();
  if (count($panel_regions)) {
    foreach ($panel_regions as $panel_name => $panels_list) {
      $panel_markup = theme("render_panel", array(
        'page' => $vars['page'],
        'panels_list' => $panels_list,
        'regions_width' => $vars['regions_width'],
      ));
      $panel_markup = trim($panel_markup);
      $vars['page'][$panel_name] = empty($panel_markup) ? FALSE : array('content' => array('#markup' => $panel_markup));
    }
  }

  $current_skin = theme_get_setting('skin');
  if (isset($_COOKIE['weebpal_skin'])) {
    $current_skin = $_COOKIE['weebpal_skin'];
  }

  $layout_width = (theme_get_setting('layout_width') == '')
  ? theme_get_setting('layout_width_default')
  : theme_get_setting('layout_width');
  $vars['page']['show_skins_menu'] = $show_skins_menu = theme_get_setting('show_skins_menu');

  if($show_skins_menu) {
    $current_layout = theme_get_setting('layout');
    if (isset($_COOKIE['weebpal_layout'])) {
      $current_layout = $_COOKIE['weebpal_layout'];
    }

    if ($current_layout == 'layout-boxed') {
      $vars['page_css'] = 'style="max-width:' . $layout_width . 'px;margin: 0 auto;" class="boxed"';
    }
    $data = array(
      'layout_width' => $layout_width,
      'current_layout' => $current_layout
      );
    $skins_menu = theme_render_template(drupal_get_path('theme', 'sushibar') . '/tpl/skins-menu.tpl.php', $data);
    $vars['page']['show_skins_menu'] = $skins_menu;
  }

  $vars['page']['weebpal_skin_classes'] = !empty($current_skin) ? ($current_skin . "-skin") : "";
  if (!empty($current_skin) && $current_skin != 'default' && theme_get_setting("default_logo") && theme_get_setting("toggle_logo")) {
    $vars['logo'] = file_create_url(drupal_get_path('theme', $theme_key)) . "/css/colors/" . $current_skin . "/images/logo.png";
  }

  $skin = theme_get_setting('skin');
  if (isset($_COOKIE['weebpal_skin'])) {
    $skin = $_COOKIE['weebpal_skin'] == 'default' ? '' : $_COOKIE['weebpal_skin'];
  }
  if (!empty($skin) && file_exists(drupal_get_path('theme', $theme_key) . "/css/colors/" . $skin . "/style.css")) {
    drupal_add_css(drupal_get_path('theme', $theme_key) . "/css/colors/" . $skin . "/style.css", array(
      'group' => CSS_THEME,
      ));
  }

}


/**
 * Hook preprocess render panel.
 */
function sushibar_preprocess_render_panel(&$variables) {
  $page = $variables['page'];
  $panels_list = $variables['panels_list'];
  $regions_width = $variables['regions_width'];
  $variables = array();
  $variables['page'] = array();
  $variables['panel_width'] = $regions_width;
  $variables['panel_classes'] = array();
  $variables['panels_list'] = $panels_list;
  $is_empty = TRUE;
  $panel_keys = array_keys($panels_list);

  foreach ($panels_list as $panel) {
    $variables['page'][$panel] = $page[$panel];
    $panel_width = $regions_width[$panel];
    if (render($page[$panel])) {
      $is_empty = FALSE;
    }
    $classes = array("panel-column");
    // $classes[] = "col-lg-$panel_width";
    // $classes[] = "col-md-$panel_width";
    $classes[] = "col-sm-$panel_width";
    // $classes[] = "col-xs-$panel_width";
    $classes[] = str_replace("_", "-", $panel);
    $variables['panel_classes'][$panel] = implode(" ", $classes);
  }
  $variables['empty_panel'] = $is_empty;
}

/**
 * Get predefined param.
 */

function _get_predefined_param($param, $pre_array = array(), $suf_array = array()) {
  global $theme_key;
  $theme_data = list_themes();
  $result = isset($theme_data[$theme_key]->info[$param]) ? $theme_data[$theme_key]->info[$param] : array();
  return $pre_array + $result + $suf_array;
}


/**
 * Hook comment view alter.
 */
function sushibar_comment_view_alter(&$build) {
  global $user;
  if ($build['#bundle'] == 'comment_node_product' && !$user->uid) {
    unset($build['links']['comment']);
  }
}

/**
 * Hook preprocess node.
 */
function sushibar_preprocess_node(&$vars) {

  $skins = _get_predefined_param('skins', array('default' => t("Default skin")));
  foreach ($skins as $key => $val) {
    if ($vars['node_url'] == base_path() . 'skins/' . $key && (!isset($_COOKIE['light_skin']) || $_COOKIE['light_skin'] != $key)) {
      setcookie('light_skin', $key, time() + 100000, base_path());
      header('Location: ' . $vars['node_url']);
    }
  }

  if ($vars['type'] == 'blog') {
    $vars['title_link'] = FALSE;
    if (in_array('node-teaser', $vars['classes_array']) || in_array('node-preview', $vars['classes_array'])) {
      $vars['title_link'] = TRUE;
    }

    $vars['sushibar_media_field'] = false;
    foreach($vars['content'] as $key => $field) {
      if (isset($field['#field_type']) && isset($field['#weight'])) {
        if ($field['#field_type'] == 'image' || $field['#field_type'] == 'video_embed_field' || $field['#field_type'] == 'youtube') {
          $vars['sushibar_media_field'] = drupal_render($field);
          $vars['classes_array'][] = 'sushibar-media-first';
          unset($vars['content'][$key]);
          break;
        }
      }
    }

    $vars['page'] = ($vars['type'] == 'page') ? TRUE : FALSE;
    $vars['created_day'] = date('d', $vars['created']);
    $vars['created_month'] = date('M', $vars['created']);
  }

    if(isset($vars['content']['links']['comment'])) {
    $vars['comment_links'] = $vars['content']['links']['comment'];
    unset($vars['content']['links']['comment']);
  }
}

function sushibar_form_comment_form_alter(&$form, &$form_state, &$form_id) {
  $form['actions']['submit']['#value'] = t('Submit');
}
